# DB Migration

The migration object is accessed via [Database.migration][fluid.db.Database.migration] or [CrudDB][fluid.db.CrudDB.migration] and is used to create and manage database migrations.

It requires the `db` extra to be installed:

```bash
pip install aio-fluid[db]
```

::: fluid.db.Migration
